import type { NodePath, PluginPass, ConfigAPI } from '@babel/core';
import type { OutputOptions } from './handlers';
import { getEnv } from './handlers';
import type { ProcessorConfig } from './Processor';
declare type CompileOptions = {
    /**
     * Use typescript language server
     *
     * By default, true for typescript files
     * @default true
     */
    typescript: ProcessorConfig['typescript'];
    /**
     * Apply static evaluation optimizations
     *
     * @default true
     */
    evaluate: ProcessorConfig['evaluate'];
    /**
     * Use CSS Variables fallback
     * If true, then even not optimized dynamic values would be optimized as possible
     *
     * @default true
     */
    unstable_CSSVariableFallback: ProcessorConfig['CSSVariableFallback'];
    /**
     * Based on static analysis remove unused bindings after compilation
     *
     * @default true
     */
    unstable_optimizeBindings: ProcessorConfig['optimizeBindings'];
    /**
     * Support tagged template literals.
     *
     * That's an experimental option that might be deprecated.
     *
     * @default false;
     */
    unstable_useTaggedTemplateLiterals: boolean;
};
export declare type MacroConfig = Partial<{
    env?: ReturnType<typeof getEnv>;
    compileOptions: Partial<CompileOptions>;
    outputOptions: Partial<OutputOptions>;
}>;
export declare type MacroOptions = {
    state: PluginPass;
    babel: ConfigAPI;
    config?: MacroConfig;
    references: Record<string, NodePath[]>;
};
export declare function macro({ references, babel, state, config: _config, }: MacroOptions): {
    keepImports: boolean;
} | undefined;
export {};
